@@ -24,7 +24,11 @@ namespace NETGeographicLib
    * the geodesic from point 1 to point 2 has azimuths \e azi1 and \e azi2 at
    * the two end points.  (The azimuth is the heading measured clockwise from
    * north.  \e azi2 is the "forward" azimuth, i.e., the heading that takes you
-   * beyond point 2 not back to point 1.)
+   * beyond point 2 not back to point 1.)  In the figure below, latitude if
+   * labeled &phi;, longitude &lambda; (with &lambda;<sub>12</sub> =
+   * &lambda;<sub>2</sub> &minus; &lambda;<sub>1</sub>), and azimuth &alpha;.
+   *
+   * <img src="http://upload.wikimedia.org/wikipedia/commons/c/cb/Geodesic_problem_on_an_ellipsoid.svg" width=250 alt="spheroidal triangle">
    *
    * Given \e lat1, \e lon1, \e azi1, and \e s12, we can determine \e lat2, \e
    * lon2, and \e azi2.  This is the \e direct geodesic problem and its
@@ -67,7 +71,6 @@ namespace NETGeographicLib
    *   defined similarly (with the geodesics being parallel at point 2).  On a
    *   flat surface, we have \e M12 = \e M21 = 1.  The quantity 1/\e M12 gives
    *   the scale of the Cassini-Soldner projection.
-
    * - <i>area</i>.  The area between the geodesic from point 1 to point 2 and
    *   the equation is represented by \e S12; it is the area, measured
    *   counter-clockwise, of the geodesic quadrilateral with corners
@@ -96,17 +99,17 @@ namespace NETGeographicLib
    * (obviously) uniquely defined.  However, in a few special cases there are
    * multiple azimuths which yield the same shortest distance.  Here is a
    * catalog of those cases:
-   * - \e lat1 = &minus;\e lat2 (with neither at a pole).  If \e azi1 = \e
-   *   azi2, the geodesic is unique.  Otherwise there are two geodesics and the
-   *   second one is obtained by setting [\e azi1, \e azi2] = [\e azi2, \e
+   * - \e lat1 = &minus;\e lat2 (with neither point at a pole).  If \e azi1 =
+   *   \e azi2, the geodesic is unique.  Otherwise there are two geodesics and
+   *   the second one is obtained by setting [\e azi1, \e azi2] = [\e azi2, \e
    *   azi1], [\e M12, \e M21] = [\e M21, \e M12], \e S12 = &minus;\e S12.
    *   (This occurs when the longitude difference is near &plusmn;180&deg; for
    *   oblate ellipsoids.)
-   * - \e lon2 = \e lon1 &plusmn; 180&deg; (with neither at a pole).  If \e
-   *   azi1 = 0&deg; or &plusmn;180&deg;, the geodesic is unique.  Otherwise
+   * - \e lon2 = \e lon1 &plusmn; 180&deg; (with neither point at a pole).  If
+   *   \e azi1 = 0&deg; or &plusmn;180&deg;, the geodesic is unique.  Otherwise
    *   there are two geodesics and the second one is obtained by setting [\e
    *   azi1, \e azi2] = [&minus;\e azi1, &minus;\e azi2], \e S12 = &minus;\e
-   *   S12.  (This occurs when the \e lat2 is near &minus;\e lat1 for prolate
+   *   S12.  (This occurs when \e lat2 is near &minus;\e lat1 for prolate
    *   ellipsoids.)
    * - Points 1 and 2 at opposite poles.  There are infinitely many geodesics
    *   which can be generated by setting [\e azi1, \e azi2] = [\e azi1, \e
@@ -137,10 +140,10 @@ namespace NETGeographicLib
    *
    * The algorithms are described in
    * - C. F. F. Karney,
-   *   <a href="http://dx.doi.org/10.1007/s00190-012-0578-z">
+   *   <a href="https://dx.doi.org/10.1007/s00190-012-0578-z">
    *   Algorithms for geodesics</a>,
    *   J. Geodesy <b>87</b>, 43--55 (2013);
-   *   DOI: <a href="http://dx.doi.org/10.1007/s00190-012-0578-z">
+   *   DOI: <a href="https://dx.doi.org/10.1007/s00190-012-0578-z">
    *   10.1007/s00190-012-0578-z</a>;
    *   addenda: <a href="http://geographiclib.sf.net/geod-addenda.html">
    *   geod-addenda.html</a>.
@@ -173,7 +176,77 @@ namespace NETGeographicLib
         // Frees the unmanaged memory when this object is destroyed.
         !Geodesic();
     public:
-        /** \name Constructor
+        /**
+         * Bit masks for what calculations to do.  These masks do double duty.
+         * They signify to the GeodesicLine::GeodesicLine constructor and to
+         * Geodesic::Line what capabilities should be included in the GeodesicLine
+         * object.  They also specify which results to return in the general
+         * routines Geodesic::GenDirect and Geodesic::GenInverse routines.
+         * GeodesicLine::mask is a duplication of this enum.
+         **********************************************************************/
+        enum class mask {
+         /**
+          * No capabilities, no output.
+          * @hideinitializer
+          **********************************************************************/
+         NONE          = 0U,
+         /**
+          * Calculate latitude \e lat2.  (It's not necessary to include this as a
+          * capability to GeodesicLine because this is included by default.)
+          * @hideinitializer
+          **********************************************************************/
+         LATITUDE      = 1U<<7  | unsigned(captype::CAP_NONE),
+         /**
+          * Calculate longitude \e lon2.
+          * @hideinitializer
+          **********************************************************************/
+         LONGITUDE     = 1U<<8  | unsigned(captype::CAP_C3),
+         /**
+          * Calculate azimuths \e azi1 and \e azi2.  (It's not necessary to
+          * include this as a capability to GeodesicLine because this is included
+          * by default.)
+          * @hideinitializer
+          **********************************************************************/
+         AZIMUTH       = 1U<<9  | unsigned(captype::CAP_NONE),
+         /**
+          * Calculate distance \e s12.
+          * @hideinitializer
+          **********************************************************************/
+         DISTANCE      = 1U<<10 | unsigned(captype::CAP_C1),
+         /**
+          * Allow distance \e s12 to be used as input in the direct geodesic
+          * problem.
+          * @hideinitializer
+          **********************************************************************/
+         DISTANCE_IN   = 1U<<11 | unsigned(captype::CAP_C1) | unsigned(captype::CAP_C1p),
+         /**
+          * Calculate reduced length \e m12.
+          * @hideinitializer
+          **********************************************************************/
+         REDUCEDLENGTH = 1U<<12 | unsigned(captype::CAP_C1) | unsigned(captype::CAP_C2),
+         /**
+          * Calculate geodesic scales \e M12 and \e M21.
+          * @hideinitializer
+          **********************************************************************/
+         GEODESICSCALE = 1U<<13 | unsigned(captype::CAP_C1) | unsigned(captype::CAP_C2),
+         /**
+          * Calculate area \e S12.
+          * @hideinitializer
+          **********************************************************************/
+         AREA          = 1U<<14 | unsigned(captype::CAP_C4),
+         /**
+          * Do not wrap the \e lon2 in the direct calculation.
+          * @hideinitializer
+          **********************************************************************/
+         LONG_NOWRAP   = 1U<<15,
+         /**
+          * All capabilities, calculate everything.  (LONG_NOWRAP is not
+          * included in this mask.)
+          * @hideinitializer
+          **********************************************************************/
+         ALL           = unsigned(captype::OUT_ALL)| unsigned(captype::CAP_ALL),
+       };
+       /** \name Constructor
          **********************************************************************/
         ///@{
         /**
@@ -415,7 +488,7 @@ namespace NETGeographicLib
          * @param[in] s12_a12 if \e arcmode is false, this is the distance between
          *   point 1 and point 2 (meters); otherwise it is the arc length between
          *   point 1 and point 2 (degrees); it can be negative.
-         * @param[in] outmask a bitor'ed combination of NETGeographicLib::Mask values
+         * @param[in] outmask a bitor'ed combination of Geodesic::mask values
          *   specifying which of the following parameters should be set.
          * @param[out] lat2 latitude of point 2 (degrees).
          * @param[out] lon2 longitude of point 2 (degrees).
@@ -429,28 +502,35 @@ namespace NETGeographicLib
          * @param[out] S12 area under the geodesic (meters<sup>2</sup>).
          * @return \e a12 arc length of between point 1 and point 2 (degrees).
          *
-         * The NETGeographicLib::Mask values possible for \e outmask are
-         * - \e outmask |= NETGeographicLib::Mask::LATITUDE for the latitude \e lat2;
-         * - \e outmask |= NETGeographicLib::Mask::LONGITUDE for the latitude \e lon2;
-         * - \e outmask |= NETGeographicLib::Mask::AZIMUTH for the latitude \e azi2;
-         * - \e outmask |= NETGeographicLib::Mask::DISTANCE for the distance \e s12;
-         * - \e outmask |= NETGeographicLib::Mask::REDUCEDLENGTH for the reduced length \e
+         * The Geodesic::mask values possible for \e outmask are
+         * - \e outmask |= Geodesic::LATITUDE for the latitude \e lat2;
+         * - \e outmask |= Geodesic::LONGITUDE for the latitude \e lon2;
+         * - \e outmask |= Geodesic::AZIMUTH for the latitude \e azi2;
+         * - \e outmask |= Geodesic::DISTANCE for the distance \e s12;
+         * - \e outmask |= Geodesic::REDUCEDLENGTH for the reduced length \e
          *   m12;
-         * - \e outmask |= NETGeographicLib::Mask::GEODESICSCALE for the geodesic scales \e
+         * - \e outmask |= Geodesic::GEODESICSCALE for the geodesic scales \e
          *   M12 and \e M21;
-         * - \e outmask |= NETGeographicLib::Mask::AREA for the area \e S12;
-         * - \e outmask |= NETGeographicLib::Mask::ALL for all of the above.
+         * - \e outmask |= Geodesic::AREA for the area \e S12;
+         * - \e outmask |= Geodesic::ALL for all of the above;
+         * - \e outmask |= Geodesic::LONG_NOWRAP stops the returned value of \e
+         *   lon2 being wrapped into the range [&minus;180&deg;, 180&deg;).
          * .
          * The function value \e a12 is always computed and returned and this
          * equals \e s12_a12 is \e arcmode is true.  If \e outmask includes
-         * NETGeographicLib::Mask::DISTANCE and \e arcmode is false, then
-         * \e s12 = \e s12_a12.  It is not necessary to include
-         * NETGeographicLib::Mask::DISTANCE_IN in \e outmask; this is
-         * automatically included is \e arcmode is false.
+         * Geodesic::DISTANCE and \e arcmode is false, then \e s12 = \e s12_a12.
+         * It is not necessary to include Geodesic::DISTANCE_IN in \e outmask; this
+         * is automatically included is \e arcmode is false.
+         *
+         * With the LONG_NOWRAP bit set, the quantity \e lon2 &minus; \e lon1
+         * indicates how many times the geodesic wrapped around the ellipsoid.
+         * Because \e lon2 might be outside the normal allowed range for
+         * longitudes, [&minus;540&deg;, 540&deg;), be sure to normalize it with
+         * Math::AngNormalize2 before using it in other GeographicLib calls.
          **********************************************************************/
         double GenDirect(double lat1, double lon1, double azi1,
                         bool arcmode, double s12_a12,
-                        NETGeographicLib::Mask outmask,
+                        Geodesic::mask outmask,
                         [System::Runtime::InteropServices::Out] double% lat2,
                         [System::Runtime::InteropServices::Out] double% lon2,
                         [System::Runtime::InteropServices::Out] double% azi2,
@@ -598,7 +678,7 @@ namespace NETGeographicLib
          * The arc length is always computed and returned as the function value.
          **********************************************************************/
         double GenInverse(double lat1, double lon1, double lat2, double lon2,
-                        NETGeographicLib::Mask outmask,
+                        Geodesic::mask outmask,
                         [System::Runtime::InteropServices::Out] double% s12,
                         [System::Runtime::InteropServices::Out] double% azi1,
                         [System::Runtime::InteropServices::Out] double% azi2,
