@@ -45,13 +45,96 @@ namespace NETGeographicLib
    **********************************************************************/
     public ref class GeodesicLineExact
     {
-        private:
+    private:
+        enum class captype {
+          CAP_NONE = 0U,
+          CAP_E    = 1U<<0,
+          // Skip 1U<<1 for compatibility with Geodesic (not required)
+          CAP_D    = 1U<<2,
+          CAP_H    = 1U<<3,
+          CAP_C4   = 1U<<4,
+          CAP_ALL  = 0x1FU,
+          CAP_MASK = CAP_ALL,
+          OUT_ALL  = 0x7F80U,
+          OUT_MASK = 0xFF80U,       // Includes LONG_NOWRAP
+        };
         // a pointer to the GeographicLib::GeodesicLineExact.
         const GeographicLib::GeodesicLineExact* m_pGeodesicLineExact;
 
         // the finalizer frees the unmanaged memory when the object is destroyed.
         !GeodesicLineExact(void);
     public:
+        /**
+         * Bit masks for what calculations to do.  These masks do double duty.
+         * They signify to the GeodesicLineExact::GeodesicLineExact constructor and
+         * to GeodesicExact::Line what capabilities should be included in the
+         * GeodesicLineExact object.  They also specify which results to return in
+         * the general routines GeodesicExact::GenDirect and
+         * GeodesicExact::GenInverse routines.  GeodesicLineExact::mask is a
+         * duplication of this enum.
+         **********************************************************************/
+        enum class mask {
+          /**
+           * No capabilities, no output.
+           * @hideinitializer
+           **********************************************************************/
+          NONE          = 0U,
+          /**
+           * Calculate latitude \e lat2.  (It's not necessary to include this as a
+           * capability to GeodesicLineExact because this is included by default.)
+           * @hideinitializer
+           **********************************************************************/
+          LATITUDE      = 1U<<7  | unsigned(captype::CAP_NONE),
+          /**
+           * Calculate longitude \e lon2.
+           * @hideinitializer
+           **********************************************************************/
+          LONGITUDE     = 1U<<8  | unsigned(captype::CAP_H),
+          /**
+           * Calculate azimuths \e azi1 and \e azi2.  (It's not necessary to
+           * include this as a capability to GeodesicLineExact because this is
+           * included by default.)
+           * @hideinitializer
+           **********************************************************************/
+          AZIMUTH       = 1U<<9  | unsigned(captype::CAP_NONE),
+          /**
+           * Calculate distance \e s12.
+           * @hideinitializer
+           **********************************************************************/
+          DISTANCE      = 1U<<10 | unsigned(captype::CAP_E),
+          /**
+           * Allow distance \e s12 to be used as input in the direct geodesic
+           * problem.
+           * @hideinitializer
+           **********************************************************************/
+          DISTANCE_IN   = 1U<<11 | unsigned(captype::CAP_E),
+          /**
+           * Calculate reduced length \e m12.
+           * @hideinitializer
+           **********************************************************************/
+          REDUCEDLENGTH = 1U<<12 | unsigned(captype::CAP_D),
+          /**
+           * Calculate geodesic scales \e M12 and \e M21.
+           * @hideinitializer
+           **********************************************************************/
+          GEODESICSCALE = 1U<<13 | unsigned(captype::CAP_D),
+          /**
+           * Calculate area \e S12.
+           * @hideinitializer
+           **********************************************************************/
+          AREA          = 1U<<14 | unsigned(captype::CAP_C4),
+          /**
+           * Do not wrap the \e lon2 in the direct calculation.
+           * @hideinitializer
+           **********************************************************************/
+          LONG_NOWRAP   = 1U<<15,
+          /**
+           * All capabilities, calculate everything.  (LONG_NOWRAP is not
+           * included in this mask.)
+           * @hideinitializer
+           **********************************************************************/
+          ALL           = unsigned(captype::OUT_ALL)| unsigned(captype::CAP_ALL),
+        };
 
         /** \name Constructors
          **********************************************************************/
@@ -335,7 +418,7 @@ namespace NETGeographicLib
          * @param[in] s12_a12 if \e arcmode is false, this is the distance between
          *   point 1 and point 2 (meters); otherwise it is the arc length between
          *   point 1 and point 2 (degrees); it can be signed.
-         * @param[in] outmask a bitor'ed combination of NETGeographicLib::Mask
+         * @param[in] outmask a bitor'ed combination of GeodesicLineExact::mask
          *   values specifying which of the following parameters should be set.
          * @param[out] lat2 latitude of point 2 (degrees).
          * @param[out] lon2 longitude of point 2 (degrees); requires that the
@@ -359,25 +442,33 @@ namespace NETGeographicLib
          *   GeodesicLineExact::AREA.
          * @return \e a12 arc length of between point 1 and point 2 (degrees).
          *
-         * The NETGeographicLib::Mask values possible for \e outmask are
-         * - \e outmask |= NETGeographicLib::Mask::LATITUDE for the latitude \e lat2;
-         * - \e outmask |= NETGeographicLib::Mask::LONGITUDE for the latitude \e lon2;
-         * - \e outmask |= NETGeographicLib::Mask::AZIMUTH for the latitude \e azi2;
-         * - \e outmask |= NETGeographicLib::Mask::DISTANCE for the distance \e s12;
-         * - \e outmask |= NETGeographicLib::Mask::REDUCEDLENGTH for the reduced length
+         * The GeodesicLineExact::mask values possible for \e outmask are
+         * - \e outmask |= GeodesicLineExact::LATITUDE for the latitude \e lat2;
+         * - \e outmask |= GeodesicLineExact::LONGITUDE for the latitude \e lon2;
+         * - \e outmask |= GeodesicLineExact::AZIMUTH for the latitude \e azi2;
+         * - \e outmask |= GeodesicLineExact::DISTANCE for the distance \e s12;
+         * - \e outmask |= GeodesicLineExact::REDUCEDLENGTH for the reduced length
          *   \e m12;
-         * - \e outmask |= NETGeographicLib::Mask::GEODESICSCALE for the geodesic scales
+         * - \e outmask |= GeodesicLineExact::GEODESICSCALE for the geodesic scales
          *   \e M12 and \e M21;
-         * - \e outmask |= NETGeographicLib::Mask::AREA for the area \e S12;
-         * - \e outmask |= NETGeographicLib::Mask::ALL for all of the above.
+         * - \e outmask |= GeodesicLineExact::AREA for the area \e S12;
+         * - \e outmask |= GeodesicLineExact::ALL for all of the above;
+         * - \e outmask |= GeodesicLineExact::LONG_NOWRAP stops the returned value
+         *   of \e lon2 being wrapped into the range [&minus;180&deg;, 180&deg;).
          * .
          * Requesting a value which the GeodesicLineExact object is not capable of
          * computing is not an error; the corresponding argument will not be
          * altered.  Note, however, that the arc length is always computed and
          * returned as the function value.
+         *
+         * With the LONG_NOWRAP bit set, the quantity \e lon2 &minus; \e lon1
+         * indicates how many times the geodesic wrapped around the ellipsoid.
+         * Because \e lon2 might be outside the normal allowed range for
+         * longitudes, [&minus;540&deg;, 540&deg;), be sure to normalize it with
+         * Math::AngNormalize2 before using it in other GeographicLib calls.
          **********************************************************************/
         double GenPosition(bool arcmode, double s12_a12,
-                NETGeographicLib::Mask outmask,
+                GeodesicLineExact::mask outmask,
                 [System::Runtime::InteropServices::Out] double% lat2,
                 [System::Runtime::InteropServices::Out] double% lon2,
                 [System::Runtime::InteropServices::Out] double% azi2,
