@@ -2,7 +2,7 @@
  * \file DMS.hpp
  * \brief Header for GeographicLib::DMS class
  *
- * Copyright (c) Charles Karney (2008-2011) <charles@karney.com> and licensed
+ * Copyright (c) Charles Karney (2008-2015) <charles@karney.com> and licensed
  * under the MIT/X11 License.  For more information, see
  * http://geographiclib.sourceforge.net/
  **********************************************************************/
@@ -32,26 +32,6 @@ namespace GeographicLib {
    * \include example-DMS.cpp
    **********************************************************************/
   class GEOGRAPHICLIB_EXPORT DMS {
-  private:
-    typedef Math::real real;
-    // Replace all occurrences of pat by c
-    static void replace(std::string& s, const std::string& pat, char c) {
-      std::string::size_type p = 0;
-      while (true) {
-        p = s.find(pat, p);
-        if (p == std::string::npos)
-          break;
-        s.replace(p, pat.length(), 1, c);
-      }
-    }
-    static const std::string hemispheres_;
-    static const std::string signs_;
-    static const std::string digits_;
-    static const std::string dmsindicators_;
-    static const std::string components_[3];
-    static Math::real NumMatch(const std::string& s);
-    DMS();                      // Disable constructor
-
   public:
 
     /**
@@ -108,6 +88,29 @@ namespace GeographicLib {
       SECOND = 2,
     };
 
+  private:
+    typedef Math::real real;
+    // Replace all occurrences of pat by c
+    static void replace(std::string& s, const std::string& pat, char c) {
+      std::string::size_type p = 0;
+      while (true) {
+        p = s.find(pat, p);
+        if (p == std::string::npos)
+          break;
+        s.replace(p, pat.length(), 1, c);
+      }
+    }
+    static const std::string hemispheres_;
+    static const std::string signs_;
+    static const std::string digits_;
+    static const std::string dmsindicators_;
+    static const std::string components_[3];
+    static Math::real NumMatch(const std::string& s);
+    static Math::real InternalDecode(const std::string& dmsa, flag& ind);
+    DMS();                      // Disable constructor
+
+  public:
+
     /**
      * Convert a string in DMS to an angle.
      *
@@ -120,24 +123,25 @@ namespace GeographicLib {
      * Degrees, minutes, and seconds are indicated by the characters d, '
      * (single quote), &quot; (double quote), and these components may only be
      * given in this order.  Any (but not all) components may be omitted and
-     * other symbols (e.g., the &deg; symbol for degrees and the unicode
-     * prime and double prime symbols for minutes and seconds) may be
-     * substituted.  The last component indicator may be omitted and is assumed
-     * to be the next smallest unit (thus 33d10 is interpreted as 33d10').  The
-     * final component may be a decimal fraction but the non-final components
-     * must be integers.  Instead of using d, ', and &quot; to indicate
-     * degrees, minutes, and seconds, : (colon) may be used to <i>separate</i>
-     * these components (numbers must appear before and after each colon); thus
-     * 50d30'10.3&quot; may be written as 50:30:10.3, 5.5' may be written
-     * 0:5.5, and so on.  The integer parts of the minutes and seconds
-     * components must be less than 60.  A single leading sign is permitted.  A
-     * hemisphere designator (N, E, W, S) may be added to the beginning or end
-     * of the string.  The result is multiplied by the implied sign of the
-     * hemisphere designator (negative for S and W).  In addition \e ind is set
-     * to DMS::LATITUDE if N or S is present, to DMS::LONGITUDE if E or W is
-     * present, and to DMS::NONE otherwise.  Throws an error on a malformed
-     * string.  No check is performed on the range of the result.  Examples of
-     * legal and illegal strings are
+     * other symbols (e.g., the &deg; symbol for degrees and the unicode prime
+     * and double prime symbols for minutes and seconds) may be substituted;
+     * two single quotes can be used instead of &quot;.  The last component
+     * indicator may be omitted and is assumed to be the next smallest unit
+     * (thus 33d10 is interpreted as 33d10').  The final component may be a
+     * decimal fraction but the non-final components must be integers.  Instead
+     * of using d, ', and &quot; to indicate degrees, minutes, and seconds, :
+     * (colon) may be used to <i>separate</i> these components (numbers must
+     * appear before and after each colon); thus 50d30'10.3&quot; may be
+     * written as 50:30:10.3, 5.5' may be written 0:5.5, and so on.  The
+     * integer parts of the minutes and seconds components must be less
+     * than 60.  A single leading sign is permitted.  A hemisphere designator
+     * (N, E, W, S) may be added to the beginning or end of the string.  The
+     * result is multiplied by the implied sign of the hemisphere designator
+     * (negative for S and W).  In addition \e ind is set to DMS::LATITUDE if N
+     * or S is present, to DMS::LONGITUDE if E or W is present, and to
+     * DMS::NONE otherwise.  Throws an error on a malformed string.  No check
+     * is performed on the range of the result.  Examples of legal and illegal
+     * strings are
      * - <i>LEGAL</i> (all the entries on each line are equivalent)
      *   - -20.51125, 20d30'40.5&quot;S, -20&deg;30'40.5, -20d30.675,
      *     N-20d30'40.5&quot;, -20:30:40.5
@@ -147,15 +151,29 @@ namespace GeographicLib {
      *   - 4d5&quot;4', 4::5, 4:5:, :4:5, 4d4.5'4&quot;, -N20.5, 1.8e2d, 4:60,
      *     4d-5'
      *
+     * The decoding operation can also perform a single addition or subtraction
+     * operation.  If the string includes an <i>internal</i> sign (i.e., not at
+     * the beginning nor immediately after an initial hemisphere designator),
+     * then the string is split immediately before that sign and each half is
+     * decoded according to the above rules and the results added.  The second
+     * half can include a hemisphere designator, but it must come at the end (a
+     * hemisphere designator is not allowed after the initial sign).  If both
+     * halves include hemisphere designators then these must compatible; e.g.,
+     * you cannot mix N and E.  Examples of legal and illegal combinations are
+     * - <i>LEGAL</i> (these are all equivalent)
+     *   - 070:00:45, 70:01:15W+0:0.5, 70:01:15W-0:0:30W, W70:01:15+0:0:30E
+     * - <i>ILLEGAL</i> (the exception thrown explains the problem)
+     *   - 70:01:15W+0:0:15N, W70:01:15+W0:0:15
+     *
      * <b>NOTE:</b> At present, all the string handling in the C++
      * implementation %GeographicLib is with 8-bit characters.  The support for
      * unicode symbols for degrees, minutes, and seconds is therefore via the
-     * <a href="http://en.wikipedia.org/wiki/UTF-8">UTF-8</a> encoding.  (The
+     * <a href="https://en.wikipedia.org/wiki/UTF-8">UTF-8</a> encoding.  (The
      * JavaScript implementation of this class uses unicode natively, of
      * course.)
      *
      * Here is the list of Unicode symbols supported for degrees, minutes,
-     * seconds:
+     * seconds, and the sign:
      * - degrees:
      *   - d, D lower and upper case letters
      *   - U+00b0 degree symbol (&deg;)
@@ -172,6 +190,8 @@ namespace GeographicLib {
      *   - U+2033 double prime (&Prime;)
      *   - U+201d right double quote (&rdquo;)
      *   - '&nbsp;' any two consecutive symbols for minutes
+     * - leading sign:
+     *   - U+2212 minus sign (&minus;)
      * .
      * The codes with a leading zero byte, e.g., U+00b0, are accepted in their
      * UTF-8 coded form 0xc2 0xb0 and as a single byte 0xb0.
@@ -281,7 +301,8 @@ namespace GeographicLib {
      *
      * @param[in] angle input angle (degrees)
      * @param[in] trailing DMS::component value indicating the trailing units
-     *   on the string and this is given as a decimal number if necessary.
+     *   of the string (this component is given as a decimal number if
+     *   necessary).
      * @param[in] prec the number of digits after the decimal point for the
      *   trailing component.
      * @param[in] ind DMS::flag value indicated additional formatting.
