@@ -2,7 +2,7 @@
  * \file Geoid.hpp
  * \brief Header for GeographicLib::Geoid class
  *
- * Copyright (c) Charles Karney (2009-2012) <charles@karney.com> and licensed
+ * Copyright (c) Charles Karney (2009-2015) <charles@karney.com> and licensed
  * under the MIT/X11 License.  For more information, see
  * http://geographiclib.sourceforge.net/
  **********************************************************************/
@@ -51,6 +51,13 @@ namespace GeographicLib {
    * this class evaluates the height by interpolation into a grid of
    * precomputed values.
    *
+   * The geoid height, \e N, can be used to convert a height above the
+   * ellipsoid, \e h, to the corresponding height above the geoid (roughly the
+   * height above mean sea level), \e H, using the relations
+   *
+   * &nbsp;&nbsp;&nbsp;\e h = \e N + \e H;
+   * &nbsp;&nbsp;\e H = &minus;\e N + \e h.
+   *
    * See \ref geoid for details of how to install the data sets, the data
    * format, estimates of the interpolation errors, and how to use caching.
    *
@@ -61,7 +68,8 @@ namespace GeographicLib {
    * heights.  As a result of the way that the geoid data is stored, the
    * calculation of gradients can result in large quantization errors.  This is
    * particularly acute for fine grids, at high latitudes, and for the easterly
-   * gradient.
+   * gradient.  For this reason, the use of this facility is <b>DEPRECATED</b>.
+   * Instead, use the GravityModel class to evaluate the gravity vector.
    *
    * This class is typically \e not thread safe in that a single instantiation
    * cannot be safely used by multiple threads because of the way the object
@@ -146,7 +154,8 @@ namespace GeographicLib {
         }
         try {
           filepos(ix, iy);
-          char a, b;
+          // initial values to suppress warnings in case get fails
+          char a = 0, b = 0;
           _file.get(a);
           _file.get(b);
           unsigned r = ((unsigned char)(a) << 8) | (unsigned char)(b);
@@ -301,13 +310,14 @@ namespace GeographicLib {
      *   never happens if (\e lat, \e lon) is within a successfully cached area.
      * @return geoid height (meters).
      *
-     * The latitude should be in [&minus;90&deg;, 90&deg;] and
-     * longitude should be in [&minus;540&deg;, 540&deg;).  As a result
-     * of the way that the geoid data is stored, the calculation of gradients
-     * can result in large quantization errors.  This is particularly acute for
-     * fine grids, at high latitudes, and for the easterly gradient.  If you
-     * need to compute the direction of the acceleration due to gravity
-     * accurately, you should use GravityModel::Gravity.
+     * The latitude should be in [&minus;90&deg;, 90&deg;] and longitude should
+     * be in [&minus;540&deg;, 540&deg;).  As a result of the way that the
+     * geoid data is stored, the calculation of gradients can result in large
+     * quantization errors.  This is particularly acute for fine grids, at high
+     * latitudes, and for the easterly gradient.  For this reason, the
+     * computation of the gradient is <b>DEPRECATED</b>.  If you need to
+     * compute the direction of the acceleration due to gravity accurately, you
+     * should use GravityModel::Gravity.
      **********************************************************************/
     Math::real operator()(real lat, real lon, real& gradn, real& grade) const {
       return height(lat, lon, true, gradn, grade);
