@@ -2,7 +2,7 @@
  * \file Utility.hpp
  * \brief Header for GeographicLib::Utility class
  *
- * Copyright (c) Charles Karney (2011-2012) <charles@karney.com> and licensed
+ * Copyright (c) Charles Karney (2011-2014) <charles@karney.com> and licensed
  * under the MIT/X11 License.  For more information, see
  * http://geographiclib.sourceforge.net/
  **********************************************************************/
@@ -15,11 +15,12 @@
 #include <vector>
 #include <sstream>
 #include <cctype>
+#include <ctime>
 
 #if defined(_MSC_VER)
-// Squelch warnings about constant conditional expressions
+// Squelch warnings about constant conditional expressions and unsafe gmtime
 #  pragma warning (push)
-#  pragma warning (disable: 4127)
+#  pragma warning (disable: 4127 4996)
 #endif
 
 namespace GeographicLib {
@@ -165,7 +166,8 @@ namespace GeographicLib {
     /**
      * Given a date as a string in the format yyyy, yyyy-mm, or yyyy-mm-dd,
      * return the numeric values for the year, month, and day.  No checking is
-     * done on these values.
+     * done on these values.  The string "now" is interpreted as the present
+     * date (in UTC).
      *
      * @param[in] s the date in string format.
      * @param[out] y the year.
@@ -174,6 +176,14 @@ namespace GeographicLib {
      * @exception GeographicErr is \e s is malformed.
      **********************************************************************/
     static void date(const std::string& s, int& y, int& m, int& d) {
+      if (s == "now") {
+        std::time_t t = std::time(0);
+        struct tm* now = gmtime(&t);
+        y = now->tm_year + 1900;
+        m = now->tm_mon + 1;
+        d = now->tm_mday;
+        return;
+      }
       int y1, m1 = 1, d1 = 1;
       const char* digits = "0123456789";
       std::string::size_type p1 = s.find_first_not_of(digits);
@@ -286,6 +296,19 @@ namespace GeographicLib {
         return x < 0 ? std::string("-inf") :
           (x > 0 ? std::string("inf") : std::string("nan"));
       std::ostringstream s;
+#if GEOGRAPHICLIB_PRECISION == 4
+      // boost-quadmath treats precision == 0 as "use as many digits as
+      // necessary", so...
+      using std::floor;
+      if (p == 0) {
+        long long ix = (long long)(floor(x + Math::real(0.5)));
+        // Implement the "round ties to even" rule
+        if (Math::real(ix) == x + Math::real(0.5) && (ix % 2) == 1)
+          --ix;
+        s << ix;
+        return s.str();
+      }
+#endif
       if (p >= 0) s << std::fixed << std::setprecision(p);
       s << x; return s.str();
     }
@@ -406,7 +429,7 @@ namespace GeographicLib {
           std::numeric_limits<ExtT>::is_integer)
         {
           // Data is compatible (aside from the issue of endian-ness).
-          str.read(reinterpret_cast<char *>(array), num * sizeof(ExtT));
+          str.read(reinterpret_cast<char*>(array), num * sizeof(ExtT));
           if (!str.good())
             throw GeographicErr("Failure reading data");
           if (bigendp != Math::bigendian) { // endian mismatch -> swap bytes
@@ -423,7 +446,7 @@ namespace GeographicLib {
           int i = 0;                // index into output array
           while (k) {
             int n = (std::min)(k, bufsize);
-            str.read(reinterpret_cast<char *>(buffer), n * sizeof(ExtT));
+            str.read(reinterpret_cast<char*>(buffer), n * sizeof(ExtT));
             if (!str.good())
               throw GeographicErr("Failure reading data");
             for (int j = 0; j < n; ++j)
@@ -452,7 +475,8 @@ namespace GeographicLib {
     template<typename ExtT, typename IntT, bool bigendp>
       static inline void readarray(std::istream& str,
                                    std::vector<IntT>& array) {
-      readarray<ExtT, IntT, bigendp>(str, &array[0], array.size());
+      if (array.size() > 0)
+        readarray<ExtT, IntT, bigendp>(str, &array[0], array.size());
     }
 
     /**
@@ -477,7 +501,7 @@ namespace GeographicLib {
           bigendp == Math::bigendian)
         {
           // Data is compatible (including endian-ness).
-          str.write(reinterpret_cast<const char *>(array), num * sizeof(ExtT));
+          str.write(reinterpret_cast<const char*>(array), num * sizeof(ExtT));
           if (!str.good())
             throw GeographicErr("Failure writing data");
         }
@@ -494,7 +518,7 @@ namespace GeographicLib {
               // cast to ExtT and fix endian-ness
               buffer[j] = bigendp == Math::bigendian ? ExtT(array[i++]) :
                 Math::swab<ExtT>(ExtT(array[i++]));
-            str.write(reinterpret_cast<const char *>(buffer), n * sizeof(ExtT));
+            str.write(reinterpret_cast<const char*>(buffer), n * sizeof(ExtT));
             if (!str.good())
               throw GeographicErr("Failure writing data");
             k -= n;
@@ -517,7 +541,8 @@ namespace GeographicLib {
     template<typename ExtT, typename IntT, bool bigendp>
       static inline void writearray(std::ostream& str,
                                    std::vector<IntT>& array) {
-      writearray<ExtT, IntT, bigendp>(str, &array[0], array.size());
+      if (array.size() > 0)
+        writearray<ExtT, IntT, bigendp>(str, &array[0], array.size());
     }
 
     /**
