@@ -1,7 +1,7 @@
 /**
  * Implementation of the net.sf.geographiclib.PolygonArea class
  *
- * Copyright (c) Charles Karney (2013) <charles@karney.com> and licensed
+ * Copyright (c) Charles Karney (2013-2014) <charles@karney.com> and licensed
  * under the MIT/X11 License.  For more information, see
  * http://geographiclib.sourceforge.net/
  **********************************************************************/
@@ -15,17 +15,14 @@ package net.sf.geographiclib;
  * <ul>
  * <li>
  *   C. F. F. Karney,
- *   <a href="http://dx.doi.org/10.1007/s00190-012-0578-z">
+ *   <a href="https://dx.doi.org/10.1007/s00190-012-0578-z">
  *   Algorithms for geodesics</a>,
- *   J. Geodesy <b>87</b>, 43&ndash;55 (2013);
- *   DOI: <a href="http://dx.doi.org/10.1007/s00190-012-0578-z">
- *   10.1007/s00190-012-0578-z</a>;
- *   addenda: <a href="http://geographiclib.sf.net/geod-addenda.html">
- *   geod-addenda.html</a>.
+ *   J. Geodesy <b>87</b>, 43&ndash;55 (2013)
+ *   (<a href="http://geographiclib.sf.net/geod-addenda.html">addenda</a>).
  * </ul>
  * <p>
  * This class lets you add vertices one at a time to the polygon.  The area
- * and perimeter are accumulated in two times the standard floating point
+ * and perimeter are accumulated at two times the standard floating point
  * precision to guard against the loss of accuracy with many-sided polygons.
  * At any point you can ask for the perimeter and area so far.  There's an
  * option to treat the points as defining a polyline instead of a polygon; in
@@ -81,6 +78,17 @@ public class PolygonArea {
       (lon2 < 0 && lon1 >= 0 && lon12 < 0 ? -1 : 0);
     return cross;
   }
+  // an alternate version of transit to deal with longitudes in the direct
+  // problem.
+  private static int transitdirect(double lon1, double lon2) {
+    // We want to compute exactly
+    //   int(floor(lon2 / 360)) - int(floor(lon1 / 360))
+    // Since we only need the parity of the result we can use std::remquo but
+    // this is buggy with g++ 4.8.3 and requires C++11.  So instead we do
+    lon1 = lon1 % 720.0; lon2 = lon2 % 720.0;
+    return ( ((lon2 >= 0 && lon2 < 360) || lon2 < -360 ? 0 : 1) -
+             ((lon1 >= 0 && lon1 < 360) || lon1 < -360 ? 0 : 1) );
+    }
 
   /**
    * Constructor for PolygonArea.
@@ -95,7 +103,8 @@ public class PolygonArea {
     _polyline = polyline;
      _mask = GeodesicMask.LATITUDE | GeodesicMask.LONGITUDE |
        GeodesicMask.DISTANCE |
-       (_polyline ? GeodesicMask.NONE : GeodesicMask.AREA);
+       (_polyline ? GeodesicMask.NONE :
+        GeodesicMask.AREA | GeodesicMask.LONG_NOWRAP);
      _perimetersum = new Accumulator(0);
      if (!_polyline)
        _areasum = new Accumulator(0);
@@ -155,7 +164,7 @@ public class PolygonArea {
       _perimetersum.Add(g.s12);
       if (!_polyline) {
         _areasum.Add(g.S12);
-        _crossings += transit(_lon1, g.lon2);
+        _crossings += transitdirect(_lon1, g.lon2);
       }
       _lat1 = g.lat2; _lon1 = g.lon2;
       ++_num;
@@ -329,7 +338,7 @@ public class PolygonArea {
       GeodesicData g =
         _earth.Direct(_lat1, _lon1, azi, false, s, _mask);
       tempsum += g.S12;
-      crossings += transit(_lon1, g.lon2);
+      crossings += transitdirect(_lon1, g.lon2);
       g = _earth.Inverse(g.lat2, g.lon2, _lat0, _lon0, _mask);
       perimeter += g.s12;
       tempsum += g.S12;
