@@ -7,8 +7,8 @@
 #
 #    http://geographiclib.sourceforge.net/html/annotated.html
 #
-# Copyright (c) Charles Karney (2011) <charles@karney.com> and licensed under
-# the MIT/X11 License.  For more information, see
+# Copyright (c) Charles Karney (2011-2014) <charles@karney.com> and licensed
+# under the MIT/X11 License.  For more information, see
 # http://geographiclib.sourceforge.net/
 ######################################################################
 
@@ -24,7 +24,9 @@ class GeodesicCapability(object):
   CAP_C3   = 1 << 3
   CAP_C4   = 1 << 4
   CAP_ALL  = 0x1F
+  CAP_MASK = CAP_ALL
   OUT_ALL  = 0x7F80
+  OUT_MASK = 0xFF80             # Includes LONG_NOWRAP
   EMPTY         = 0
   LATITUDE      = 1 << 7  | CAP_NONE
   LONGITUDE     = 1 << 8  | CAP_C3
@@ -34,5 +36,5 @@ class GeodesicCapability(object):
   REDUCEDLENGTH = 1 << 12 | CAP_C1 | CAP_C2
   GEODESICSCALE = 1 << 13 | CAP_C1 | CAP_C2
   AREA          = 1 << 14 | CAP_C4
-  ALL           = OUT_ALL | CAP_ALL
-
+  LONG_NOWRAP   = 1 << 15
+  ALL           = OUT_ALL | CAP_ALL # Does not include LONG_NOWRAP
