@@ -2,7 +2,7 @@
  * \file Geodesic.cpp
  * \brief Implementation for GeographicLib::Geodesic class
  *
- * Copyright (c) Charles Karney (2009-2013) <charles@karney.com> and licensed
+ * Copyright (c) Charles Karney (2009-2015) <charles@karney.com> and licensed
  * under the MIT/X11 License.  For more information, see
  * http://geographiclib.sourceforge.net/
  *
@@ -62,9 +62,8 @@ namespace GeographicLib {
     , _n(_f / ( 2 - _f))
     , _b(_a * _f1)
     , _c2((Math::sq(_a) + Math::sq(_b) *
-           (_e2 == 0 ? 1 :
-            (_e2 > 0 ? Math::atanh(sqrt(_e2)) : atan(sqrt(-_e2))) /
-            sqrt(abs(_e2))))/2) // authalic radius squared
+           Math::eatanhe(real(1), (_f < 0 ? -1 : 1) * sqrt(abs(_e2))) / _e2)
+          / 2) // authalic radius squared
       // The sig12 threshold for "really short".  Using the auxiliary sphere
       // solution with dnm computed at (bet1 + bet2) / 2, the relative error in
       // the azimuth consistency check is sig12^2 * abs(f) * min(1, 1-f/2) / 2.
@@ -139,20 +138,20 @@ namespace GeographicLib {
                                   real& s12, real& azi1, real& azi2,
                                   real& m12, real& M12, real& M21, real& S12)
     const {
-    outmask &= OUT_ALL;
+    outmask &= OUT_MASK;
     // Compute longitude difference (AngDiff does this carefully).  Result is
     // in [-180, 180] but -180 is only for west-going geodesics.  180 is for
     // east-going and meridional geodesics.
     real lon12 = Math::AngDiff(Math::AngNormalize(lon1),
                                Math::AngNormalize(lon2));
     // If very close to being on the same half-meridian, then make it so.
-    lon12 = AngRound(lon12);
+    lon12 = Math::AngRound(lon12);
     // Make longitude difference positive.
     int lonsign = lon12 >= 0 ? 1 : -1;
     lon12 *= lonsign;
     // If really close to the equator, treat as on equator.
-    lat1 = AngRound(lat1);
-    lat2 = AngRound(lat2);
+    lat1 = Math::AngRound(lat1);
+    lat2 = Math::AngRound(lat2);
     // Swap points so that point with higher (abs) latitude is point 1
     int swapp = abs(lat1) >= abs(lat2) ? 1 : -1;
     if (swapp < 0) {
@@ -181,13 +180,13 @@ namespace GeographicLib {
     // Ensure cbet1 = +epsilon at poles
     sbet1 = _f1 * sin(phi);
     cbet1 = lat1 == -90 ? tiny_ : cos(phi);
-    SinCosNorm(sbet1, cbet1);
+    Math::norm(sbet1, cbet1);
 
     phi = lat2 * Math::degree();
     // Ensure cbet2 = +epsilon at poles
     sbet2 = _f1 * sin(phi);
     cbet2 = abs(lat2) == 90 ? tiny_ : cos(phi);
-    SinCosNorm(sbet2, cbet2);
+    Math::norm(sbet2, cbet2);
 
     // If cbet1 < -sbet1, then cbet2 - cbet1 is a sensitive measure of the
     // |bet1| - |bet2|.  Alternatively (cbet1 >= -sbet1), abs(sbet2) + sbet1 is
@@ -214,7 +213,8 @@ namespace GeographicLib {
       slam12 = abs(lon12) == 180 ? 0 : sin(lam12),
       clam12 = cos(lam12);      // lon12 == 90 isn't interesting
 
-    real a12, sig12, calp1, salp1, calp2, salp2;
+    // initial values to suppress warning
+    real a12, sig12, calp1, salp1, calp2 = 0, salp2 = 0;
     // index zero elements of these arrays are unused
     real C1a[nC1_ + 1], C2a[nC2_ + 1], C3a[nC3_];
 
@@ -258,7 +258,7 @@ namespace GeographicLib {
         meridian = false;
     }
 
-    real omg12;
+    real omg12 = 0;             // initial value to suppress warning
     if (!meridian &&
         sbet1 == 0 &&   // and sbet2 == 0
         // Mimic the way Lambda12 works with calp1 = 0
@@ -306,7 +306,9 @@ namespace GeographicLib {
         // value of alp1 is then further from the solution) or if the new
         // estimate of alp1 lies outside (0,pi); in this case, the new starting
         // guess is taken to be (alp1a + alp1b) / 2.
-        real ssig1, csig1, ssig2, csig2, eps;
+        //
+        // initial values to suppress warnings (if loop is executed 0 times)
+        real ssig1 = 0, csig1 = 0, ssig2 = 0, csig2 = 0, eps = 0;
         unsigned numit = 0;
         // Bracketing range
         real salp1a = tiny_, calp1a = 1, salp1b = tiny_, calp1b = -1;
@@ -337,7 +339,7 @@ namespace GeographicLib {
             if (nsalp1 > 0 && abs(dalp1) < Math::pi()) {
               calp1 = calp1 * cdalp1 - salp1 * sdalp1;
               salp1 = nsalp1;
-              SinCosNorm(salp1, calp1);
+              Math::norm(salp1, calp1);
               // In some regimes we don't get quadratic convergence because
               // slope -> 0.  So use convergence conditions based on epsilon
               // instead of sqrt(epsilon).
@@ -355,7 +357,7 @@ namespace GeographicLib {
           // WGS84 and random input: mean = 4.74, sd = 0.99
           salp1 = (salp1a + salp1b)/2;
           calp1 = (calp1a + calp1b)/2;
-          SinCosNorm(salp1, calp1);
+          Math::norm(salp1, calp1);
           tripn = false;
           tripb = (abs(salp1a - salp1) + (calp1a - calp1) < tolb_ ||
                    abs(salp1 - salp1b) + (calp1 - calp1b) < tolb_);
@@ -394,8 +396,8 @@ namespace GeographicLib {
           eps = k2 / (2 * (1 + sqrt(1 + k2)) + k2),
           // Multiplier = a^2 * e^2 * cos(alpha0) * sin(alpha0).
           A4 = Math::sq(_a) * calp0 * salp0 * _e2;
-        SinCosNorm(ssig1, csig1);
-        SinCosNorm(ssig2, csig2);
+        Math::norm(ssig1, csig1);
+        Math::norm(ssig2, csig2);
         real C4a[nC4_];
         C4f(eps, C4a);
         real
@@ -408,7 +410,7 @@ namespace GeographicLib {
 
       if (!meridian &&
           omg12 < real(0.75) * Math::pi() && // Long difference too big
-          sbet2 - sbet1 < real(1.75)) {            // Lat difference too big
+          sbet2 - sbet1 < real(1.75)) {      // Lat difference too big
         // Use tan(Gamma/2) = tan(omg12/2)
         // * (tan(bet1/2)+tan(bet2/2))/(1+tan(bet1/2)*tan(bet2/2))
         // with tan(x/2) = sin(x)/(1+cos(x))
@@ -451,8 +453,8 @@ namespace GeographicLib {
 
     if (outmask & AZIMUTH) {
       // minus signs give range [-180, 180). 0- converts -0 to +0.
-      azi1 = 0 - atan2(-salp1, calp1) / Math::degree();
-      azi2 = 0 - atan2(-salp2, calp2) / Math::degree();
+      azi1 = Math::atan2d(salp1, calp1);
+      azi2 = Math::atan2d(salp2, calp2);
     }
 
     // Returned value in [0, 180]
@@ -608,7 +610,7 @@ namespace GeographicLib {
       salp2 = cbet1 * somg12;
       calp2 = sbet12 - cbet1 * sbet2 *
         (comg12 >= 0 ? Math::sq(somg12) / (1 + comg12) : 1 - comg12);
-      SinCosNorm(salp2, calp2);
+      Math::norm(salp2, calp2);
       // Set return value
       sig12 = atan2(ssig12, csig12);
     } else if (abs(_n) > real(0.1) || // Skip astroid calc if too eccentric
@@ -707,8 +709,9 @@ namespace GeographicLib {
         calp1 = sbet12a - cbet2 * sbet1 * Math::sq(somg12) / (1 - comg12);
       }
     }
-    if (salp1 > 0)              // Sanity check on starting guess
-      SinCosNorm(salp1, calp1);
+    // Sanity check on starting guess.  Backwards check allows NaN through.
+    if (!(salp1 <= 0))
+      Math::norm(salp1, calp1);
     else {
       salp1 = 1; calp1 = 0;
     }
@@ -742,8 +745,8 @@ namespace GeographicLib {
     // tan(omg1) = sin(alp0) * tan(sig1) = tan(omg1)=tan(alp1)*sin(bet1)
     ssig1 = sbet1; somg1 = salp0 * sbet1;
     csig1 = comg1 = calp1 * cbet1;
-    SinCosNorm(ssig1, csig1);
-    // SinCosNorm(somg1, comg1); -- don't need to normalize!
+    Math::norm(ssig1, csig1);
+    // Math::norm(somg1, comg1); -- don't need to normalize!
 
     // Enforce symmetries in the case abs(bet2) = -bet1.  Need to be careful
     // about this case, since this can yield singularities in the Newton
@@ -764,8 +767,8 @@ namespace GeographicLib {
     // tan(omg2) = sin(alp0) * tan(sig2).
     ssig2 = sbet2; somg2 = salp0 * sbet2;
     csig2 = comg2 = calp2 * cbet2;
-    SinCosNorm(ssig2, csig2);
-    // SinCosNorm(somg2, comg2); -- don't need to normalize!
+    Math::norm(ssig2, csig2);
+    // Math::norm(somg2, comg2); -- don't need to normalize!
 
     // sig12 = sig2 - sig1, limit to [0, pi]
     sig12 = atan2(max(csig1 * ssig2 - ssig1 * csig2, real(0)),
