@@ -2,8 +2,8 @@
  * \file MagneticModel.cpp
  * \brief Implementation for GeographicLib::MagneticModel class
  *
- * Copyright (c) Charles Karney (2011) <charles@karney.com> and licensed under
- * the MIT/X11 License.  For more information, see
+ * Copyright (c) Charles Karney (2011-2015) <charles@karney.com> and licensed
+ * under the MIT/X11 License.  For more information, see
  * http://geographiclib.sourceforge.net/
  **********************************************************************/
 
@@ -22,7 +22,7 @@
 #endif
 
 #if !defined(GEOGRAPHICLIB_MAGNETIC_DEFAULT_NAME)
-#  define GEOGRAPHICLIB_MAGNETIC_DEFAULT_NAME "wmm2010"
+#  define GEOGRAPHICLIB_MAGNETIC_DEFAULT_NAME "wmm2015"
 #endif
 
 #if defined(_MSC_VER)
@@ -173,7 +173,9 @@ namespace GeographicLib {
     real X, Y, Z;
     real M[Geocentric::dim2_];
     _earth.IntForward(lat, lon, h, X, Y, Z, M);
-    real BX0, BY0, BZ0, BX1, BY1, BZ1; // Components in geocentric basis
+    // Components in geocentric basis
+    // initial values to suppress warning
+    real BX0 = 0, BY0 = 0, BZ0 = 0, BX1 = 0, BY1 = 0, BZ1 = 0;
     _harm[n](X, Y, Z, BX0, BY0, BZ0);
     _harm[n + 1](X, Y, Z, BX1, BY1, BZ1);
     if (interpolate) {
@@ -219,11 +221,11 @@ namespace GeographicLib {
                                       real& Dt, real& It) {
     H = Math::hypot(Bx, By);
     Ht = H ? (Bx * Bxt + By * Byt) / H : Math::hypot(Bxt, Byt);
-    D = (0 - (H ? atan2(-Bx, By) : atan2(-Bxt, Byt))) / Math::degree();
+    D = H ? Math::atan2d(Bx, By) : Math::atan2d(Bxt, Byt);
     Dt = (H ? (By * Bxt - Bx * Byt) / Math::sq(H) : 0) / Math::degree();
     F = Math::hypot(H, Bz);
     Ft = F ? (H * Ht + Bz * Bzt) / F : Math::hypot(Ht, Bzt);
-    I = (F ? atan2(-Bz, H) : atan2(-Bzt, Ht)) / Math::degree();
+    I = F ? Math::atan2d(-Bz, H) : Math::atan2d(-Bzt, Ht);
     It = (F ? (Bz * Ht - H * Bzt) / Math::sq(F) : 0) / Math::degree();
   }
 
