@@ -2,12 +2,12 @@
  * \file TransverseMercatorExact.cpp
  * \brief Implementation for GeographicLib::TransverseMercatorExact class
  *
- * Copyright (c) Charles Karney (2008-2011) <charles@karney.com> and licensed
+ * Copyright (c) Charles Karney (2008-2015) <charles@karney.com> and licensed
  * under the MIT/X11 License.  For more information, see
  * http://geographiclib.sourceforge.net/
  *
  * The relevant section of Lee's paper is part V, pp 67--101,
- * <a href="http://dx.doi.org/10.3138/X687-1574-4325-WM62">Conformal
+ * <a href="https://dx.doi.org/10.3138/X687-1574-4325-WM62">Conformal
  * Projections Based On Jacobian Elliptic Functions</a>.
  *
  * The method entails using the Thompson Transverse Mercator as an
@@ -83,34 +83,6 @@ namespace GeographicLib {
     return utm;
   }
 
-  // tau = tan(phi), taup = sinh(psi)
-  Math::real TransverseMercatorExact::taup(real tau) const {
-    real
-      tau1 = Math::hypot(real(1), tau),
-      sig = sinh( _e * Math::atanh(_e * tau / tau1) );
-    return Math::hypot(real(1), sig) * tau - sig * tau1;
-  }
-
-  Math::real TransverseMercatorExact::taupinv(real taup) const {
-    real
-      // See comment in TransverseMercator.cpp about the initial guess
-      tau = taup/_mv,
-      stol = tol_ * max(real(1), abs(taup));
-    // min iterations = 1, max iterations = 2; mean = 1.94
-    for (int i = 0; i < numit_ || GEOGRAPHICLIB_PANIC; ++i) {
-      real
-        tau1 = Math::hypot(real(1), tau),
-        sig = sinh( _e * Math::atanh(_e * tau / tau1 ) ),
-        taupa = Math::hypot(real(1), sig) * tau - sig * tau1,
-        dtau = (taup - taupa) * (1 + _mv * Math::sq(tau)) /
-        ( _mv * tau1 * Math::hypot(real(1), taupa) );
-      tau += dtau;
-      if (!(abs(dtau) >= stol))
-        break;
-    }
-    return tau;
-  }
-
   void TransverseMercatorExact::zeta(real /*u*/, real snu, real cnu, real dnu,
                                      real /*v*/, real snv, real cnv, real dnv,
                                      real& taup, real& lam) const {
@@ -388,9 +360,8 @@ namespace GeographicLib {
       lon = 180 - lon;
     }
     real
-      phi = lat * Math::degree(),
       lam = lon * Math::degree(),
-      tau = tanx(phi);
+      tau = Math::tand(lat);
 
     // u,v = coordinates for the Thompson TM, Lee 54
     real u, v;
@@ -401,7 +372,8 @@ namespace GeographicLib {
       u = 0;
       v = _Ev.K();
     } else
-      zetainv(taup(tau), lam, u, v);
+      // tau = tan(phi), taup = sinh(psi)
+      zetainv(Math::taupf(tau, _e), lam, u, v);
 
     real snu, cnu, dnu, snv, cnv, dnv;
     _Eu.sncndn(u, snu, cnu, dnu);
@@ -420,7 +392,7 @@ namespace GeographicLib {
     } else {
       // Recompute (tau, lam) from (u, v) to improve accuracy of Scale
       zeta(u, snu, cnu, dnu, v, snv, cnv, dnv, tau, lam);
-      tau=taupinv(tau);
+      tau = Math::tauf(tau, _e);
       Scale(tau, lam, snu, cnu, dnu, snv, cnv, dnv, gamma, k);
       gamma /= Math::degree();
     }
@@ -462,15 +434,13 @@ namespace GeographicLib {
     real phi, lam, tau;
     if (v != 0 || u != _Eu.K()) {
       zeta(u, snu, cnu, dnu, v, snv, cnv, dnv, tau, lam);
-      tau = taupinv(tau);
+      tau = Math::tauf(tau, _e);
       phi = atan(tau);
       lat = phi / Math::degree();
       lon = lam / Math::degree();
       Scale(tau, lam, snu, cnu, dnu, snv, cnv, dnv, gamma, k);
       gamma /= Math::degree();
     } else {
-      tau = overflow();
-      phi = Math::pi()/2;
       lat = 90;
       lon = lam = gamma = 0;
       k = 1;
@@ -481,10 +451,6 @@ namespace GeographicLib {
     lon *= lonsign;
     lon = Math::AngNormalize(lon + Math::AngNormalize(lon0));
     lat *= latsign;
-    if (backside)
-      y = 2 * _Eu.E() - y;
-    y *= _a * _k0 * latsign;
-    x *= _a * _k0 * lonsign;
     if (backside)
       gamma = 180 - gamma;
     gamma *= latsign * lonsign;
