@@ -6,19 +6,7 @@
  * under the MIT/X11 License.  For more information, see
  * http://geographiclib.sourceforge.net/
  *
- * Compile and link with
- *   g++ -g -O3 -I../include -I../man -o MagneticField \
- *       MagneticField.cpp \
- *       ../src/CircularEngine.cpp \
- *       ../src/DMS.cpp \
- *       ../src/Geocentric.cpp \
- *       ../src/MagneticCircle.cpp \
- *       ../src/MagneticModel.cpp \
- *       ../src/SphericalEngine.cpp \
- *       ../src/Utility.cpp
- *
- * See the <a href="MagneticField.1.html">man page</a> for usage
- * information.
+ * See the <a href="MagneticField.1.html">man page</a> for usage information.
  **********************************************************************/
 
 #include <iostream>
@@ -248,10 +236,10 @@ int main(int argc, char* argv[]) {
         try {
           std::string eol("\n");
           if (!cdelim.empty()) {
-            std::string::size_type m = s.find(cdelim);
-            if (m != std::string::npos) {
-              eol = " " + s.substr(m) + "\n";
-              s = s.substr(0, m);
+            std::string::size_type n = s.find(cdelim);
+            if (n != std::string::npos) {
+              eol = " " + s.substr(n) + "\n";
+              s = s.substr(0, n);
             }
           }
           std::istringstream str(s);
