@@ -2,8 +2,8 @@
 #
 # Download magnetic models for use by GeographicLib::MagneticModel.
 #
-# Copyright (c) Charles Karney (2011) <charles@karney.com> and licensed
-# under the MIT/X11 License.  For more information, see
+# Copyright (c) Charles Karney (2011-2015) <charles@karney.com> and
+# licensed under the MIT/X11 License.  For more information, see
 # http://geographiclib.sourceforge.net/
 
 DEFAULTDIR="@GEOGRAPHICLIB_DATA@"
@@ -25,16 +25,16 @@ table:
                                   size (kB)
   name     degree    years      tar.bz2  disk
   wmm2010    12    2010-2015      2       3
+  wmm2015    12    2015-2020      2       3
   igrf11     13    1900-2015      7      25
+  igrf12     13    1900-2020      7      26
   emm2010   740    2010-2015    3700    4400
 
 The size columns give the download and installed sizes of the datasets.
 In addition you can specify
 
   all = all of the supported magnetic models
-  minimal = wmm2010 igrf11
-
-If no name is specified then minimal is assumed.
+  minimal = wmm2015 igrf12
 
 -p parentdir (default $DEFAULTDIR) specifies where the
 datasets should be stored.  The "Default $NAME path" listed when running
@@ -79,6 +79,10 @@ while getopts hp:fd c; do
     esac
 done
 shift `expr $OPTIND - 1`
+if test $# -eq 0; then
+    usage 1>&2;
+    exit 1
+fi
 
 test -d "$PARENTDIR"/$SUBDIR || mkdir -p "$PARENTDIR"/$SUBDIR 2> /dev/null
 if test ! -d "$PARENTDIR"/$SUBDIR; then
@@ -110,12 +114,12 @@ set -e
 
 cat > $TEMP/all <<EOF
 wmm2010
+wmm2015
 emm2010
 igrf11
+igrf12
 EOF
 
-test $# -eq 0 && set -- minimal
-
 while test $# -gt 0; do
     if grep "^$1\$" $TEMP/all > /dev/null; then
 	echo $1
@@ -124,8 +128,8 @@ while test $# -gt 0; do
 	    all )
 		cat $TEMP/all
 		;;
-	    minimal )		# same as no argument
-		echo wmm2010; echo igrf11
+	    minimal )
+		echo wmm2015; echo igrf12
 		;;
 	    * )
 		echo Unknown magnetic model $1 1>&2
